# Home page
get '/' do
  erb :home
end

# Playlists overview page
get '/playlists' do
  erb :playlists
end

# Specific playlist page
get '/playlists/:id' do
  @title = PlayList.get(params[:id]).name
  @playlist = Song.get_playlist(params[:id])
  erb :playlist
end

# Submit an iTunes XML Playlist
post '/postxml' do

  # Check to ensure that a file is selected for upload
  unless params[:file] && (tmpfile = params[:file][:tempfile]) && (name = params[:file][:filename])
    @error = "No file selected"
    erb :error
  end

  # Construct the file and filepath
  path = File.join('tmp', params[:file][:filename]) 
  File.open(path, 'wb') { |f| f.write(tmpfile.read) }
  
  # Get the nokogiri object
  xml = load_xml(path)

  # Parse the playlist out of the Nokogiri XML object
  playlist = create_playlist(xml)

  # Save the playlist to the database
  params[:id] = save_playlist playlist, params[:playlist_title]
  Resque.enqueue(Itunes, params[:id])

  # Pass information to playlist template
  @playlist = Song.get_playlist(params[:id])
  @title = params[:playlist_title]
  erb :playlist
end

# Load the XML as a Nokogiri object
def load_xml(xml)
  doc = Nokogiri::XML(File.open(xml, 'r')) 
end

# Create an array representation of the playlist from the XML
def create_playlist(xml)
  playlist = []
  xml.xpath('/plist/dict/dict/dict').each do |track| 
    hash = {} 
    key = nil 
    track.children.each do |attribute|
      if attribute.name == 'key' 
        key = attribute.text 
      elsif attribute.name == 'string'
        hash[key] = attribute.text 
      end 
    end
    playlist << hash
  end
  playlist
end

# Save the playlist to the database
def save_playlist(playlist, playlist_title)
  @playlist = PlayList.create(
    :name => playlist_title,
    :posted => Time.now
  )
  playlist.each do |track|
    @song = Song.create(
      :title => track['Name'],
      :album => track['Album'],
      :artist => track['Artist'],
      :play_list_id => @playlist.id
    )
  end
  @playlist.id
end

# Get the iTunes links for each track
def get_itunes_data(title, artist, album)
  api_url = "http://ax.itunes.apple.com/WebObjects/MZStoreServices.woa/wa/wsSearch?term="
  search_term = CGI::escape(title + ' ' + artist)
  query = api_url + search_term + '&entity=musicTrack'
  results = RestClient.get query
  playlist = JSON.parse(results)
  playlist["results"][0]
end
