require File.dirname(__FILE__) + '/spec_helper'
require 'spec'
require 'spec/interop/test'

describe 'controllers' do
  include Rack::Test::Methods
    
  def app
    @app ||= Sinatra::Application
  end
  
  describe 'get /'  do
    it "should render a front page" do
      get '/'
      last_response.should be_ok
    end
  end

  describe 'get /playlists' do
    it "should render a list of playlists" do
      get '/playlists'
      last_response.should be_ok
    end
  end

  describe 'get /playlists/:id' do
    it "should render a specific playlist" do
      get '/playlists/1'
      last_response.should be_ok
    end
    
    it "should render the correct title for the specific playlist" do
      get '/playlists/21'
      last_response.body.should include("African Archives Vol 1")
    end 
  end

  describe 'post /postxml' do
    it "executes successfully" do
      post '/postxml', :file => Rack::Test::UploadedFile.new(fixture_path('testplaylist.xml'))
      last_response.should be_ok
    end

    it "saves the playlist with the correct attributes" do
      lambda { post '/postxml', :file => Rack::Test::UploadedFile.new(fixture_path('testplaylist.xml')) }.should change(PlayList, :count)
      p PlayList.count
      flunk
    end

    it "something about Songs" do
    end

  end

  describe "load_xml" do
    it "should return a valid Nokogiri xml document object" do
      doc = load_xml(fixture_path("testplaylist.xml"))
      doc.class.should == Nokogiri::XML::Document
    end
  end

  describe "create_playlist" do
    it "should return an array of individual songs" do
      xml = load_xml(fixture_path("testplaylist.xml"))
      playlist = create_playlist(xml)
      playlist[0]['Name'].should == "Purple Haze"
      playlist[0]['Artist'].should== "The Jimi Hendrix Experience"
      playlist[0]['Album'].should== "Are You Experienced? [1993 Rerelease]"
    end
  end

  describe 'get_itunes_data' do
    API_URL = "http://ax.itunes.apple.com/WebObjects/MZStoreServices.woa/wa/wsSearch?term="

    it "should return an array containing one result if the search returns one results" do
      stub_request(:get, API_URL + 'purple+haze+jimi+hendrix+are+you+experienced&entity=musicTrack').to_return(:body => fixture("oneresult.json"))
      get_itunes_data('purple haze', 'jimi hendrix', 'are you experienced')
      WebMock.should have_requested(:get,"#{API_URL}purple+haze+jimi+hendrix+are+you+experienced&entity=musicTrack")
    end
  end
end
